==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/encryption_otr/translations/encryption_otr_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Tworzenie klucza prywatnego</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Tworzenie klucza prywatnego zakończone</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Włącz prywatne rozmowy</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatycznie rozpoczynaj prywatną rozmowę</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Wymagaj prywatnej rozmowy</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Używaj konfiguracji konta</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Włącz prywatne rozmowy</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatycznie rozpoczynaj prywatną rozmowę</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Wymagaj prywatnej rozmowy</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Rozpocznij prywatną rozmowę</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>Zakończ prywatną rozmowę</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Zweryfikuj tożsamość rozmówcy</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Odśwież prywatną rozmowę</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>Niezweryfikowany rozmówca</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Rozmowa jest prywatna</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>Rozmowa nie jest prywatna</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Wystąpił błąd podczas szyfrowania wiadomości</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>Użytkownik %1 otrzymał zaszyfrowaną wiadomość, ale się tego nie spodziewał</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>Została wysłana nieczytelna zaszyfrowana wiadomość</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>Została wysłana niepoprawnie zaszyfrowana wiadomość</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Nieszyfrowanie wiadomości do %1 nie są dozwolone. Rozpoczynanie prywatnej rozmowy...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Błąd szyfrowania. Wiadomość nie została wysłana.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>Wiadomość nie została wysłana. %1 zakończył prywatną rozmowę. Należy odświeżyć lub zakończyć prywatną rozmowę.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Błąd podczas ustawiania prywatnej rozmowy z %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>Otrzymujemy własne wiadomości OTR od %1. Należy odświeżyć lub zakończyć prywatną rozmowę.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>Poprzednia wiadomość została wysłana ponownie: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>Wiadomość od %1 jest nieczytelna, gdyż rozmowa nie jest prywatna.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>Wiadomość od %1 jest nieczytelna.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>Wiadomość od %1 jest niepoprawnie sformatowana.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Błąd szyfrowania: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>Wiadomość od %1 jest niezaszyfrowana.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>Wiadomość od %1 nie została rozpoznana.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 wysłał wiadomość przeznaczoną dla innej sesji. Jeżeli jesteś zalogowany na różnych urządzeniach to wiadomość mogła dotrzeć na inne urządzenie.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Otrzymano niepoprawnie sformatowaną wiadomość</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[wiadomość wysłana ponownie]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: rozpoczynanie prywatnej rozmowy</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: odświeżanie prywatnej rozmowy</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: rozmówca zakończył prywatną rozmowę, powinieneś zrobić to samo</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: prywatna rozmowa rozpoczęta</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: prywatna rozmowa zakończona</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: rozmowa jest nadal prywatna</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: tworzenie klucza prywatnego, to może zająć kilka minut</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: utworzono klucz prywatny, rozmowa prywatna może zostać rozpoczęta</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: nieudane tworzenie klucza prywatnego</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Ręczna wymiana odcisków kluczy publicznych</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Twój odcisk klucza publicznego (%1:%2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>Odcisk klucza publicznego &lt;b&gt;%1&lt;/b&gt; (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>Nie mam pewności, czy powyższy odcisk klucza należy do %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>Jestem pewny, że powyższy odcisk klucza należy do %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Postęp weryfikacji</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Weryfikacja trwa...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Zadaj pytanie</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pytanie i odpowiedź</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Pytanie, na które tylko %1 zna odpowiedź:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Odpowiedz na pytanie</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Pytanie i odpowiedź</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 chce zweryfikować twoją tożsamość za pomocą metody Pytanie i odpowiedź.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>Pytanie zadane przez %1:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Wyślij wspólny sekret</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Wspólny sekret</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 chce zweryfikować twoją tożsamość za pomocą metody Wspólny sekret.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Wspólny sekret, który jest znany tylko tobie i %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Wynik weryfikacji</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>Weryfikacja %1 nieudana. Prawdopodobnie rozmawiasz z podszywającą się osobą. Możesz zamknąć rozmowę albo spróbować innej metody weryfikacji.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>Zostałeś poprawnie zweryfikowany przez %1. Teraz powinieneś zweryfikować %1.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>Weryfikacja %1 zakończona powodzeniem.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Nieznany.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Wybierz metodę weryfikacji</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pytanie i odpowiedź</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Wspólny sekret</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Ręczna wymiana odcisków kluczy publicznych</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Zadaj rozmówcy pytanie, na które znacie odpowiedź tylko oraz on/ona. Jeżeli rozmówca odpowie poprawnie, zostanie oznaczony jako zweryfikowany.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Wymień wspólny sekret z rozmówcą. Ten sekret powinien zostać wybrany wcześniej za pomocą innego bezpiecznego kanału komunikacji (na przykład bezpośrednia lub telefoniczna rozmowa).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Sprawdź ręcznie odcisk klucza rozmówcy. Informacje o odciskach powinny zostać wcześniej wymienione za pomocą innego bezpiecznego kanału komunikacji (na przykład bezpośrednia lub telefoniczna rozmowa).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Zapytaj o wspólny sekret</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Wspólny sekret</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Wspólny sekret, który jest znany tylko tobie i %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Zweryfikuj tożsamość %1</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/encryption_otr/translations/encryption_otr_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Tworzenie klucza prywatnego</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Tworzenie klucza prywatnego zakończone</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Włącz prywatne rozmowy</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatycznie rozpoczynaj prywatną rozmowę</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Wymagaj prywatnej rozmowy</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Używaj konfiguracji konta</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Włącz prywatne rozmowy</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatycznie rozpoczynaj prywatną rozmowę</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Wymagaj prywatnej rozmowy</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Rozpocznij prywatną rozmowę</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>Zakończ prywatną rozmowę</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Zweryfikuj tożsamość rozmówcy</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Odśwież prywatną rozmowę</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>Niezweryfikowany rozmówca</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Rozmowa jest prywatna</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>Rozmowa nie jest prywatna</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Wystąpił błąd podczas szyfrowania wiadomości</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>Użytkownik %1 otrzymał zaszyfrowaną wiadomość, ale się tego nie spodziewał</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>Została wysłana nieczytelna zaszyfrowana wiadomość</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>Została wysłana niepoprawnie zaszyfrowana wiadomość</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Nieszyfrowanie wiadomości do %1 nie są dozwolone. Rozpoczynanie prywatnej rozmowy...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Błąd szyfrowania. Wiadomość nie została wysłana.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>Wiadomość nie została wysłana. %1 zakończył prywatną rozmowę. Należy odświeżyć lub zakończyć prywatną rozmowę.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Błąd podczas ustawiania prywatnej rozmowy z %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>Otrzymujemy własne wiadomości OTR od %1. Należy odświeżyć lub zakończyć prywatną rozmowę.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>Poprzednia wiadomość została wysłana ponownie: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>Wiadomość od %1 jest nieczytelna, gdyż rozmowa nie jest prywatna.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>Wiadomość od %1 jest nieczytelna.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>Wiadomość od %1 jest niepoprawnie sformatowana.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Błąd szyfrowania: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>Wiadomość od %1 jest niezaszyfrowana.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>Wiadomość od %1 nie została rozpoznana.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 wysłał wiadomość przeznaczoną dla innej sesji. Jeżeli jesteś zalogowany na różnych urządzeniach to wiadomość mogła dotrzeć na inne urządzenie.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Otrzymano niepoprawnie sformatowaną wiadomość</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[wiadomość wysłana ponownie]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Szyfrowanie OTR</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: rozpoczynanie prywatnej rozmowy</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: odświeżanie prywatnej rozmowy</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: rozmówca zakończył prywatną rozmowę, powinieneś zrobić to samo</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: prywatna rozmowa rozpoczęta</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: prywatna rozmowa zakończona</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: rozmowa jest nadal prywatna</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: tworzenie klucza prywatnego, to może zająć kilka minut</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: utworzono klucz prywatny, rozmowa prywatna może zostać rozpoczęta</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: nieudane tworzenie klucza prywatnego</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Ręczna wymiana odcisków kluczy publicznych</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Twój odcisk klucza publicznego (%1:%2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>Odcisk klucza publicznego &lt;b&gt;%1&lt;/b&gt; (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>Nie mam pewności, czy powyższy odcisk klucza należy do %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>Jestem pewny, że powyższy odcisk klucza należy do %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Postęp weryfikacji</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Weryfikacja trwa...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Zadaj pytanie</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pytanie i odpowiedź</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Pytanie, na które tylko %1 zna odpowiedź:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Odpowiedz na pytanie</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Pytanie i odpowiedź</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 chce zweryfikować twoją tożsamość za pomocą metody Pytanie i odpowiedź.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>Pytanie zadane przez %1:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Wyślij wspólny sekret</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Wspólny sekret</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 chce zweryfikować twoją tożsamość za pomocą metody Wspólny sekret.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Wspólny sekret, który jest znany tylko tobie i %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Wynik weryfikacji</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>Weryfikacja %1 nieudana. Prawdopodobnie rozmawiasz z podszywającą się osobą. Możesz zamknąć rozmowę albo spróbować innej metody weryfikacji.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>Zostałeś poprawnie zweryfikowany przez %1. Teraz powinieneś zweryfikować %1.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>Weryfikacja %1 zakończona powodzeniem.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Nieznany.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Wybierz metodę weryfikacji</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pytanie i odpowiedź</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Wspólny sekret</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Ręczna wymiana odcisków kluczy publicznych</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Zadaj rozmówcy pytanie, na które znacie odpowiedź tylko oraz on/ona. Jeżeli rozmówca odpowie poprawnie, zostanie oznaczony jako zweryfikowany.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Wymień wspólny sekret z rozmówcą. Ten sekret powinien zostać wybrany wcześniej za pomocą innego bezpiecznego kanału komunikacji (na przykład bezpośrednia lub telefoniczna rozmowa).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Sprawdź ręcznie odcisk klucza rozmówcy. Informacje o odciskach powinny zostać wcześniej wymienione za pomocą innego bezpiecznego kanału komunikacji (na przykład bezpośrednia lub telefoniczna rozmowa).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Zapytaj o wspólny sekret</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Wspólny sekret</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Wspólny sekret, który jest znany tylko tobie i %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Zweryfikuj tożsamość %1</translation>
    </message>
</context>
</TS>
